merge_kobo_data: Merging data files from deviating kobo tools

Description Usage Arguments Value

Description

Merging data files from deviating kobo tools

Usage

1
2
merge_kobo_data(folder, filename_pattern = ".", output_file = NULL,
  write_log = T, use_regex = F, add_file_reference = T, verbose = T)

Arguments

folder

the path to the folder containing the files to be merged. The files must be in csv format.

filename_pattern

a search term to find files that should be merged (inside the folder). You can use R style 'regex' patterns if you set use_regex=T

output_file

full path to the file the merged dataset should be written to. If NULL (default), no output file is written.

write_log

if TRUE, writes an html file with a log of the merge and subsequent checks.

use_regex

if TRUE, searches the 'folder' directory for 'filename_pattern' using regex patterns. Defaults to FALSE.

add_file_reference

If TRUE (default), adds a new column called 'MERGED_FROM_FILE' containing the file name of each records source file.

verbose

if TRUE writes messages to console during merge; set to FALSE to make quiet.

Value

the merged data frame.


mabafaba/mergekobodata documentation built on June 7, 2019, 10:42 p.m.